summaryrefslogtreecommitdiff
path: root/include/netsurf
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2022-03-24 18:09:28 +0000
committerMichael Drake <tlsa@netsurf-browser.org>2022-03-24 18:09:28 +0000
commit002c3c1a7c2ae7229afac3f1966892fd42895aec (patch)
treebc9c769b176981296b5e92233fd623b3164a4513 /include/netsurf
parentc2d72d1e9361b3017872e5aff16cfe9a894f3048 (diff)
downloadnetsurf-002c3c1a7c2ae7229afac3f1966892fd42895aec.tar.gz
netsurf-002c3c1a7c2ae7229afac3f1966892fd42895aec.tar.bz2
Bitmap API: Clean up creation flags.
Diffstat (limited to 'include/netsurf')
-rw-r--r--include/netsurf/bitmap.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/include/netsurf/bitmap.h b/include/netsurf/bitmap.h
index db207cf58..dfd11880d 100644
--- a/include/netsurf/bitmap.h
+++ b/include/netsurf/bitmap.h
@@ -54,9 +54,12 @@
#ifndef _NETSURF_BITMAP_H_
#define _NETSURF_BITMAP_H_
-#define BITMAP_NEW 0
-#define BITMAP_OPAQUE (1 << 0) /**< image is opaque */
-#define BITMAP_CLEAR_MEMORY (1 << 2) /**< memory should be wiped */
+/** Bitmap creation flags. */
+enum gui_bitmap_flags {
+ BITMAP_NONE = 0,
+ BITMAP_OPAQUE = (1 << 0), /**< image is opaque */
+ BITMAP_CLEAR = (1 << 1), /**< memory should be wiped to 0 */
+};
struct content;
struct bitmap;
@@ -71,12 +74,12 @@ struct gui_bitmap_table {
/**
* Create a new bitmap.
*
* \param width width of image in pixels
* \param height width of image in pixels
* \param state The state to create the bitmap in.
* \return A bitmap structure or NULL on error.
*/
- void *(*create)(int width, int height, unsigned int state);
+ void *(*create)(int width, int height, enum gui_bitmap_flags flags);
/**
* Destroy a bitmap.
@@ -71,12 +74,12 @@ struct gui_bitmap_table {
* Create a new bitmap.
*
- * \param width width of image in pixels
- * \param height width of image in pixels
- * \param state The state to create the bitmap in.
+ * \param width width of image in pixels
+ * \param height height of image in pixels
+ * \param flags flags for bitmap creation
* \return A bitmap structure or NULL on error.
*/